@@ -5,7 +5,9 @@ import sys
 
 import pytest
 
-import audonnx
+import opensmile
+
+import audonnx.testing
 
 
 def uninstall(
@@ -33,16 +35,20 @@ def uninstall(
 
 def test(tmpdir):
 
+    object = audonnx.testing.create_model_proto([pytest.FEATURE_SHAPE])
     model = audonnx.Model(
-        pytest.MODEL_SINGLE_PATH,
+        object,
         transform=pytest.FEATURE,
     )
     model_path = os.path.join(tmpdir, 'model.yaml')
     model.to_yaml(model_path)
 
-    uninstall('opensmile', 'opensmile')
+    # Removing the package does not work under Windows
+    # as the DLL file cannot be unloaded
+    if not sys.platform == 'win32':
+        uninstall('opensmile', 'opensmile')
 
-    with pytest.raises(ModuleNotFoundError):
-        audonnx.load(tmpdir)
+        with pytest.raises(ModuleNotFoundError):
+            audonnx.load(tmpdir)
 
     audonnx.load(tmpdir, auto_install=True)
